<p align="center">&nbsp;</p>
<p align="center">
  <h1 align="center"><b>sec-ai</b></h1>
</p>
<p align="left">
  <!-- Using &nbsp; for alignment due to GitHub README limitations -->
  <b>Essentials ➔&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</b>
  <a href="LICENSE"><img src="https://img.shields.io/github/license/alphanome-ai/sec-ai.svg" alt="Licence"></a>
  <a href="https://project-types.github.io/#federation"><img src="https://img.shields.io/badge/project%20type-federation-brightgreen" alt="Project Type: Federation"></a>
  <a href="https://github.com/mkenney/software-guides/blob/master/STABILITY-BADGES.md#experimental"><img src="https://img.shields.io/badge/stability-experimental-orange.svg" alt="Experimental"></a>
  <br>
  <b>Health ➔&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</b>
  <a href="https://github.com/alphanome-ai/sec-ai/actions/workflows/check.yml"><img alt="GitHub Workflow Status (with event)" src="https://img.shields.io/github/actions/workflow/status/alphanome-ai/sec-ai/check.yml"></a>
  <a href="https://github.com/alphanome-ai/sec-ai/commits/main"><img alt="Last Commit" src="https://img.shields.io/github/last-commit/alphanome-ai/sec-ai"></a>  
  <br>
  <b>Quality ➔&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</b>
  <a href="https://codecov.io/gh/alphanome-ai/sec-ai"><img src="https://codecov.io/gh/alphanome-ai/sec-ai/graph/badge.svg?token=KJLA96CBCN" alt="codecov" /></a>
  <a href="https://mypy-lang.org/"><img src="https://img.shields.io/badge/type%20checked-mypy-blue.svg"></a>
  <a href="https://github.com/psf/black"><img alt="Code Style: Black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
  <a href="https://github.com/astral-sh/ruff"><img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="Ruff"></a>
  <br>
  <b>Distribution ➔&nbsp;&nbsp;&nbsp;</b>
  <a href="https://badge.fury.io/py/sec-ai"><img src="https://badge.fury.io/py/sec-ai.svg" alt="PyPI version" /></a>
  <a href="https://pypi.org/project/sec-ai/"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/sec-ai"></a>
  <a href="https://pypistats.org/packages/sec-ai"><img src="https://img.shields.io/pypi/dm/sec-ai.svg" alt="PyPI downloads"></a>
  <br>
  <b>Community ➔&nbsp;&nbsp;&nbsp;&nbsp;</b>
  <a href="http://hits.dwyl.com/alphanome-ai/sec-ai"><img src="https://img.shields.io/endpoint?url=https%3A%2F%2Fhits.dwyl.com%2Falphanome-ai%2Fsec-ai.json%3Fshow%3Dunique" alt="HitCount" /></a>
  <a href="https://twitter.com/alphanomeai"><img alt="X (formerly Twitter) Follow" src="https://img.shields.io/twitter/follow/alphanomeai"></a>
  <a href="https://github.com/alphanome-ai/sec-ai"><img src="https://img.shields.io/github/stars/alphanome-ai/sec-ai.svg?style=social&label=Star us on GitHub!" alt="GitHub stars"></a>


</p>

<div align="left">
  A comprehensive open-source toolkit for AI-powered analysis and interpretation of SEC EDGAR filings, providing valuable insights for investors, fintech developers, and researchers.
<div align="center">
</div>
  <b>
  <a href="https://github.com/alphanome-ai/sec-ai/discussions">Discussions</a> |
  <a href="https://github.com/alphanome-ai/sec-ai/issues">Issues</a> |
  <a href="https://github.com/alphanome-ai/sec-ai/issues">Backlog</a>
  </b>
</div>
<br>

# Overview

`sec-ai` is an open-source project designed to provide a comprehensive toolset for analyzing and interpreting data from SEC filings. Utilizing advanced AI technologies, this project aims to serve a wide range of users, from individual investors to researchers and regulatory bodies. 

The project leverages [`alphanome-ai/sec-parser`](https://github.com/alphanome-ai/sec-parser) for its data extraction needs, an essential component that simplifies the parsing of SEC EDGAR HTML documents into a structured and analyzable format.

# Installation

You can install `sec-ai` using pip:

```bash
pip install sec-ai
```

# Usage

```python
import sec_ai as sa
```

# License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
